****************************
so_pysm_models Documentation
****************************

This is the documentation for so_pysm_models.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   gettingstarted
   models
   highres_templates

Reference/API
=============

.. automodapi:: so_pysm_models
